<?php

namespace Drupal\fox\Plugin\FoxCommand;

/**
 * APPEND fox command.
 *
 * @FoxCommand(
 *   id = "append",
 *   label = @Translation("Append record with fields. Usage: APPEND [uField1 WITH eExpr1 [, uField2 WITH eExpr2]]")
 * )
 */
class FoxCommandAppend extends FoxCommandBaseClass {

  /**
   * {@inheritdoc}
   */
  public function execute(array $params, array $variables): array {
    $entity_type = $variables['entity_type'] ?? NULL;
    if (empty($entity_type)) {
      return [
        'error' => $this->t('Empty entity type. Use USE command.'),
      ];
    }

    $bundle = $variables['bundle'] ?? NULL;
    if (empty($entity_type)) {
      return [
        'error' => $this->t('Empty entity type. Use USE command.'),
      ];
    }

    $helper = $this->foxCommandsHelper();

    // Create entity.
    $bundle_key = $helper->entityKey($entity_type, 'bundle');
    $entity = $helper->entityTypeManager()
      ->getStorage($entity_type)
      ->create([
        $bundle_key => $bundle,
      ]);

    // Set fields.
    if (!empty($params)) {
      $param_str = implode(' ', $params);
      $items = explode(',', $param_str);
      foreach ($items as $item) {
        $replace = explode(' ', trim($item));
        if (count($replace) != 3) {
          return [
            'error' => $this->t('Bad APPEND format'),
          ];
        }
        [$field, $with, $value] = $replace;

        $with = strtolower($with);
        if ($with !== 'with') {
          return [
            'error' => $this->t('There is no wITH part'),
          ];
        }

        try {
          $entity->set($field, $value);
          $entity->save();
        }
        catch (\Exception $e) {
          return [
            'error' => $e->getMessage(),
          ];
        }
      }
    }
    else {
      try {
        $entity->save();
      }
      catch (\Exception $e) {
        return [
          'error' => $e->getMessage(),
        ];
      }
    }

    $count = $variables['count'] ?? 0;

    return [
      'message' => $this->t('Appended'),
      'variables' => [
        'id' => $entity->id(),
        'recno' => NULL,
        'count' => $count + 1,
      ],
    ];
  }

}
