<?php

namespace Drupal\fox\Plugin\FoxCommand;

/**
 * REPLACE fox command.
 *
 * @FoxCommand(
 *   id = "replace",
 *   label = @Translation("Replace fields for context record. Usage: REPLACE uField1 WITH eExpr1 [, uField2 WITH eExpr2]")
 * )
 */
class FoxCommandReplace extends FoxCommandBaseClass {

  /**
   * {@inheritdoc}
   */
  public function execute(array $params, array $variables): array {
    if (empty($params)) {
      return [
        'error' => $this->t('Empty params'),
      ];
    }

    $helper = $this->foxCommandsHelper();

    $entity = $helper->getEntity($variables);
    if (is_array($entity) and isset($entity['error'])) {
      return $entity;
    }
    if (empty($entity)) {
      return [
        'error' => $this->t('Empty entity'),
      ];
    }

    $param_str = implode(' ', $params);
    $items = explode(',', $param_str);
    foreach ($items as $item) {
      $replace = explode(' ', trim($item));
      if (count($replace) != 3) {
        return [
          'error' => $this->t('Bad REPLACE format'),
        ];
      }
      [$field, $with, $value] = $replace;

      $with = strtolower($with);
      if ($with !== 'with') {
        return [
          'error' => $this->t('There is no wITH part'),
        ];
      }

      try {
        $entity->set($field, $value);
        $entity->save();
      }
      catch (\Exception $e) {
        return [
          'error' => $e->getMessage(),
        ];
      }
    }

    return [
      'message' => $this->t('Replaced'),
    ];
  }

}
